/*
 * Copyright (c) 2010 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */

package de.intevation.artifactdatabase;

import org.apache.log4j.Logger;

import org.w3c.dom.Document;

import de.intevation.artifacts.User;
import de.intevation.artifacts.UserFactory;


/**
 * Default implementation of a UserFactory.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class DefaultUserFactory
implements   UserFactory
{
    /** The logger that is used in this factory.*/
    private static Logger logger = Logger.getLogger(DefaultUserFactory.class);


    /**
     * Default constructor.
     */
    public DefaultUserFactory() {
    }


    /**
     * This method creates a new DefaultUser with the given identifier, name and
     * role.
     *
     * @param identifier The identifier for the new user.
     * @param name The name for the new user.
     * @param role The role for the new user.
     * @param context The CallContext.
     */
    public User createUser(
        String   identifier,
        String   name,
        Document role,
        Object   context)
    {
        logger.debug("DefaultUserFactory.createUser: " + name);

        return new DefaultUser(identifier, name, role);
    }


    /**
     * Deletes the given user.
     *
     * @param user The user to be deleted.
     * @param context The CallContext.
     */
    public void deleteUser(User user, Object context) {
        logger.debug("DefaultUserFactory.deleteUser: " + user.identifier());
    }


    /**
     * Returns the user with the given identifier.
     *
     * @param identifier The identifier of a user.
     * @param context The CallContext.
     *
     * @return the user with the given identifier.
     */
    public User getUser(String identifier, Object context) {
        logger.debug("DefaultUserFactory.getUser: " + identifier);

        // TODO Implement me
        return null;
    }


    /**
     * Returns a list of users available for this application.
     *
     * @param context The CallContext.
     *
     * @return a list of users.
     */
    public User [] getUsers(Object context) {
        logger.debug("DefaultUserFactory.getUsers");

        // TODO Implement me
        return null;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
